==> openflowplugin-extension-nicira-0.7.0-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/match/rev140714/nxm/nx/nsh/flags/grouping/NxmNxNshFlags.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.nxm.nx.nsh.flags.grouping;
import java.lang.Short;
import javax.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.NxmNxNshFlagsGrouping;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-match</b>
 * <pre>
 * container nxm-nx-nsh-flags {
 *   leaf nsh-flags {
 *     type uint8;
 *   }
 *   leaf mask {
 *     type uint8;
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-match/nxm-nx-nsh-flags-grouping/nxm-nx-nsh-flags</i>
 *
 * <p>To create instances of this class use {@link NxmNxNshFlagsBuilder}.
 * @see NxmNxNshFlagsBuilder
 *
 */
public interface NxmNxNshFlags
    extends
    ChildOf<NxmNxNshFlagsGrouping>,
    Augmentable<NxmNxNshFlags>
{



    public static final QName QNAME = $YangModuleInfoImpl.qnameOf("nxm-nx-nsh-flags");

    /**
     * @return <code>java.lang.Short</code> <code>nshFlags</code>, or <code>null</code> if not present
     */
    @Nullable
    Short getNshFlags();
    
    /**
     * @return <code>java.lang.Short</code> <code>mask</code>, or <code>null</code> if not present
     */
    @Nullable
    Short getMask();

}

==> openflowplugin-extension-nicira-0.8.0-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/match/rev140714/nxm/nx/nsh/flags/grouping/NxmNxNshFlags.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.nxm.nx.nsh.flags.grouping;
import java.lang.Short;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.NxmNxNshFlagsGrouping;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-match</b>
 * <pre>
 * container nxm-nx-nsh-flags {
 *   leaf nsh-flags {
 *     type uint8;
 *   }
 *   leaf mask {
 *     type uint8;
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-match/nxm-nx-nsh-flags-grouping/nxm-nx-nsh-flags</i>
 *
 * <p>To create instances of this class use {@link NxmNxNshFlagsBuilder}.
 * @see NxmNxNshFlagsBuilder
 *
 */
public interface NxmNxNshFlags
    extends
    ChildOf<NxmNxNshFlagsGrouping>,
    Augmentable<NxmNxNshFlags>
{



    public static final QName QNAME = $YangModuleInfoImpl.qnameOf("nxm-nx-nsh-flags");

    /**
     * @return <code>java.lang.Short</code> <code>nshFlags</code>, or <code>null</code> if not present
     */
    @Nullable Short getNshFlags();
    
    /**
     * @return <code>java.lang.Short</code> <code>mask</code>, or <code>null</code> if not present
     */
    @Nullable Short getMask();

}
